@@ -56,21 +56,15 @@ def send_templated_mail(template_name, email_context, recipients, sender=None, b
     if not locale:
         locale = 'en'
 
-    if locale:
-        template_localized = template_name + ':' + locale
-    else:
-        template_localized = None
-
     t = None
-    if template_localized:
-        try:
-            t = EmailTemplate.objects.get(template_name__iexact=template_localized)
-        except EmailTemplate.DoesNotExist:
-            pass
+    try:
+        t = EmailTemplate.objects.get(template_name__iexact=template_name, locale=locale)
+    except EmailTemplate.DoesNotExist:
+        pass
 
     if not t:
         try:
-            t = EmailTemplate.objects.get(template_name__iexact=template_name)
+            t = EmailTemplate.objects.get(template_name__iexact=template_name, locale__isnull=True)
         except EmailTemplate.DoesNotExist:
             return # just ignore if template doesn't exist
 
@@ -85,6 +79,15 @@ def send_templated_mail(template_name, email_context, recipients, sender=None, b
 
     email_html_base_file = os.path.join('helpdesk', locale, 'email_html_base.html')
 
+    
+    ''' keep new lines in html emails '''
+    from django.utils.safestring import mark_safe
+    
+    if context.has_key('comment'):
+        html_txt = context['comment']
+        html_txt = html_txt.replace('\r\n', '<br>')
+        context['comment'] = mark_safe(html_txt)
+    
     html_part = loader.get_template_from_string(
         "{%% extends '%s' %%}{%% block title %%}%s{%% endblock %%}{%% block content %%}%s{%% endblock %%}" % (email_html_base_file, t.heading, t.html)
         ).render(context)
@@ -93,7 +96,10 @@ def send_templated_mail(template_name, email_context, recipients, sender=None, b
         "{{ ticket.ticket }} {{ ticket.title|safe }} %s" % t.subject
         ).render(context)
 
-    if type(recipients) != list:
+    if type(recipients) == str:
+        if recipients.find(','):
+            recipients = recipients.split(',')
+    elif type(recipients) != list:
         recipients = [recipients,]
 
     msg = EmailMultiAlternatives(   subject_part,
@@ -283,7 +289,7 @@ def safe_template_context(ticket):
         }
     queue = ticket.queue
 
-    for field in (  'title', 'slug', 'email_address', 'from_address'):
+    for field in (  'title', 'slug', 'email_address', 'from_address', 'locale'):
         attr = getattr(queue, field, None)
         if callable(attr):
             context['queue'][field] = attr()
