@@ -80,21 +80,25 @@ class Queue(models.Model):
             'increase their priority? Set to 0 for no escalation.'),
         )
 
-    new_ticket_cc = models.EmailField(
+    new_ticket_cc = models.CharField(
         _('New Ticket CC Address'),
         blank=True,
         null=True,
+        max_length=200,
         help_text=_('If an e-mail address is entered here, then it will '
-            'receive notification of all new tickets created for this queue'),
+            'receive notification of all new tickets created for this queue. '
+            'Enter a comma between multiple e-mail addresses.'),
         )
 
-    updated_ticket_cc = models.EmailField(
+    updated_ticket_cc = models.CharField(
         _('Updated Ticket CC Address'),
         blank=True,
         null=True,
+        max_length=200,
         help_text=_('If an e-mail address is entered here, then it will '
             'receive notification of all activity (new tickets, closed '
-            'tickets, updates, reassignments, etc) for this queue'),
+            'tickets, updates, reassignments, etc) for this queue. Separate '
+            'multiple addresses with a comma.'),
         )
 
     email_box_type = models.CharField(
@@ -230,12 +234,14 @@ class Ticket(models.Model):
     REOPENED_STATUS = 2
     RESOLVED_STATUS = 3
     CLOSED_STATUS = 4
+    DUPLICATE_STATUS = 5
 
     STATUS_CHOICES = (
         (OPEN_STATUS, _('Open')),
         (REOPENED_STATUS, _('Reopened')),
         (RESOLVED_STATUS, _('Resolved')),
         (CLOSED_STATUS, _('Closed')),
+        (DUPLICATE_STATUS, _('Duplicate')),        
     )
 
     PRIORITY_CHOICES = (
@@ -709,7 +715,6 @@ class EmailTemplate(models.Model):
     template_name = models.CharField(
         _('Template Name'),
         max_length=100,
-        unique=True,
         )
 
     subject = models.CharField(
@@ -740,12 +745,20 @@ class EmailTemplate(models.Model):
         help_text=_('The same context is available here as in plain_text, '
             'above.'),
         )
+    
+    locale = models.CharField(
+        _('Locale'),
+        max_length=10,
+        blank=True,
+        null=True,
+        help_text=_('Locale of this template.'),
+        )
 
     def __unicode__(self):
         return u'%s' % self.template_name
 
     class Meta:
-        ordering = ['template_name',]
+        ordering = ['template_name', 'locale']
 
 
 class KBCategory(models.Model):
@@ -804,11 +817,13 @@ class KBItem(models.Model):
     votes = models.IntegerField(
         _('Votes'),
         help_text=_('Total number of votes cast for this item'),
+        default=0,
         )
 
     recommendations = models.IntegerField(
         _('Positive Votes'),
         help_text=_('Number of votes for this item which were POSITIVE.'),
+        default=0,
         )
 
     last_updated = models.DateTimeField(
@@ -1154,6 +1169,14 @@ class CustomField(models.Model):
         null=True,
         )
 
+    def _choices_as_array(self):
+        from StringIO import StringIO
+        valuebuffer = StringIO(self.list_values)
+        choices = [[item.strip(), item.strip()] for item in valuebuffer.readlines()]
+        valuebuffer.close()
+        return choices
+    choices_as_array = property(_choices_as_array)
+
     required = models.BooleanField(
         _('Required?'),
         help_text=_('Does the user have to enter a value for this field?'),
