@@ -74,14 +74,12 @@ def dashboard(request):
             ORDER BY q.id;
     """)
     dash_tickets = query_to_dict(cursor.fetchall(), cursor.description)
-    user_saved_queries = SavedSearch.objects.filter(Q(user=request.user) | Q(shared__exact=True))
 
     return render_to_response('helpdesk/dashboard.html',
         RequestContext(request, {
             'user_tickets': tickets,
             'unassigned_tickets': unassigned_tickets,
             'dash_tickets': dash_tickets,
-            'user_saved_queries': user_saved_queries,
         }))
 dashboard = staff_member_required(dashboard)
 
@@ -135,7 +133,6 @@ def followup_edit(request, ticket_id, followup_id, ):
             
 def view_ticket(request, ticket_id):
     ticket = get_object_or_404(Ticket, id=ticket_id)
-    user_saved_queries = SavedSearch.objects.filter(Q(user=request.user) | Q(shared__exact=True))
 
     if request.GET.has_key('take'):
         # Allow the user to assign the ticket to themselves whilst viewing it.
@@ -156,7 +153,6 @@ def view_ticket(request, ticket_id):
             'owner': owner,
             'title': ticket.title,
             'comment': _('Accepted resolution and closed ticket'),
-            'user_saved_queries': user_saved_queries, 
             }
 
         return update_ticket(request, ticket_id)
@@ -164,11 +160,10 @@ def view_ticket(request, ticket_id):
     return render_to_response('helpdesk/ticket.html',
         RequestContext(request, {
             'ticket': ticket,
-            'active_users': User.objects.filter(is_active=True).filter(is_staff=True),
+            'active_users': User.objects.filter(is_active=True).filter(is_staff=True).order_by('username'),
             'priorities': Ticket.PRIORITY_CHOICES,
             'preset_replies': PreSetReply.objects.filter(Q(queues=ticket.queue) | Q(queues__isnull=True)),
             'tags_enabled': HAS_TAG_SUPPORT,
-            'user_saved_queries': user_saved_queries, 
         }))
 view_ticket = staff_member_required(view_ticket)
 
@@ -290,6 +285,9 @@ def update_ticket(request, ticket_id, public=False):
 
     messages_sent_to = []
 
+    # ticket might have changed above, so we re-instantiate context with the 
+    # (possibly) updated ticket.
+    context = safe_template_context(ticket)
     context.update(
         resolution=ticket.resolution,
         comment=f.comment,
@@ -515,6 +513,7 @@ def ticket_list(request):
                 # Go on to standard keyword searching
                 pass
 
+    saved_query = None
     if request.GET.get('saved_query', None):
         from_saved_query = True
         try:
@@ -636,6 +635,7 @@ def ticket_list(request):
             user_saved_queries=user_saved_queries,
             query_params=query_params,
             from_saved_query=from_saved_query,
+            saved_query=saved_query,
             search_message=search_message,
             tags_enabled=HAS_TAG_SUPPORT
         )))
@@ -663,7 +663,7 @@ def create_ticket(request):
     if request.method == 'POST':
         form = TicketForm(request.POST, request.FILES)
         form.fields['queue'].choices = [('', '--------')] + [[q.id, q.title] for q in Queue.objects.all()]
-        form.fields['assigned_to'].choices = [('', '--------')] + [[u.id, u.username] for u in User.objects.filter(is_active=True)]
+        form.fields['assigned_to'].choices = [('', '--------')] + [[u.id, u.username] for u in User.objects.filter(is_active=True).order_by('username')]
         if form.is_valid():
             ticket = form.save(user=request.user)
             return HttpResponseRedirect(ticket.get_absolute_url())
@@ -671,10 +671,12 @@ def create_ticket(request):
         initial_data = {}
         if request.user.usersettings.settings.get('use_email_as_submitter', False) and request.user.email:
             initial_data['submitter_email'] = request.user.email
+        if request.GET.has_key('queue'):
+            initial_data['queue'] = request.GET['queue']
 
         form = TicketForm(initial=initial_data)
         form.fields['queue'].choices = [('', '--------')] + [[q.id, q.title] for q in Queue.objects.all()]
-        form.fields['assigned_to'].choices = [('', '--------')] + [[u.id, u.username] for u in User.objects.filter(is_active=True)]
+        form.fields['assigned_to'].choices = [('', '--------')] + [[u.id, u.username] for u in User.objects.filter(is_active=True).order_by('username')]
 
     return render_to_response('helpdesk/create_ticket.html',
         RequestContext(request, {
@@ -751,6 +753,8 @@ report_index = staff_member_required(report_index)
 
 
 def run_report(request, report):
+    if Ticket.objects.all().count() == 0:
+        return HttpResponseRedirect(reverse("helpdesk_report_index"))
     priority_sql = []
     priority_columns = []
     for p in Ticket.PRIORITY_CHOICES:
@@ -894,10 +898,13 @@ def run_report(request, report):
 
     if report in ('queuemonth', 'usermonth'):
         chart_url = line_chart([columns] + data)
+        charttype = 'date'
     elif report in ('queuestatus', 'queuepriority', 'userstatus', 'userpriority'):
         chart_url = bar_chart([columns] + data)
+        charttype = 'bar'
     else:
         chart_url = ''
+        charttype = ''
 
     return render_to_response('helpdesk/report_output.html',
         RequestContext(request, {
@@ -905,6 +912,7 @@ def run_report(request, report):
             'data': data,
             'chart': chart_url,
             'title': title,
+            'charttype': charttype,
         }))
 run_report = staff_member_required(run_report)
 
